from .base_enum import BaseEnum


class Characteristic(BaseEnum):
    STANDARD = "Standard"
    ONE_SABER = "OneSaber"
    NO_ARROWS = "NoArrows"
    DEGREE_90 = "90Degree"
    DEGREE_360 = "360Degree"
    LIGHTSHOW = "Lightshow"
    LAWLESS = "Lawless"
    UNKNOWN = "Unknown"
